@@ -12,7 +12,7 @@ Readonly::Hash my %LANG => (
 	'title' => 'Page title',
 );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -131,7 +131,7 @@ Tags::HTML::Page::Begin - Tags helper for HTML page begin.
 
 =head2 C<new>
 
- my $obj = Tags::HTML::Stars->new(%params);
+ my $obj = Tags::HTML::Page::Begin->new(%params);
 
 Constructor.
 
@@ -189,6 +189,8 @@ Returns undef.
 =head1 ERRORS
 
  new():
+        Parameter 'css' must be a 'CSS::Struct::Output::*' class.
+        Parameter 'tags' must be a 'Tags::Output::*' class.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
 
@@ -263,8 +265,6 @@ Returns undef.
 
 L<Class::Utils>,
 L<Error::Pure>,
-L<List::Utils>,
-L<MIME::Base64>,
 L<Readonly>.
 
 =head1 SEE ALSO
@@ -295,6 +295,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
